@@ -908,11 +908,6 @@ class Grid:
                 'pixel_y_axis'][node] + delta_y <= self.get_image().shape[1]
             and self.get_nodes()[
                 'pixel_y_axis'][node] + delta_y >= 0)
-        print(
-            f"self.__nodes.at[node, 'pixel_x_axis'] : {self.__nodes.at[node, 'pixel_x_axis']}\ndelta_x: {delta_x}")
-        print(
-            f"self.__nodes.at[node, 'pixel_y_axis'] : {self.__nodes.at[node, 'pixel_y_axis']}\ndelta_x: {delta_y}")
-
         if new_coord_within_boundary or allow_shifting_node_outside_boundary:
             # shift node
             self.__nodes.at[node, 'pixel_x_axis'] =\
@@ -1073,8 +1068,9 @@ class Grid:
         """
         visu = GridVisualizer()
         self.__image = copy.deepcopy(self.__initial_image)
-        self.__image = visu.add_upper_margin(self.get_image(),
-                                             int(0.15 * self.get_image().shape[0]))
+        self.__image = visu.add_upper_margin(
+            self.get_image(),
+            int(0.15 * self.get_image().shape[0]))
 
     # ----------------- COMPUTE DISTANCE BETWEEN NODES -----------------#
 
